==> eole-gpo-script_2.9.0-7.tar.gz: eole-gpo-script-7/README.md <==
## gpo-script

#Démarrer un etb1 scribe avec PC Win7 (x86), PC10 (ammd64), et Win11 (amd64)

... faire les modifications de installMinion.ps1 ou ps.ps1

Vérifier le fonctionnement des 3 PC en éxecutant :
- reboot
- controler c:\windows\temp\installMinion.log
- dans la session 'admin', vérifier %TEMP%\eole_script.log

#Aller sur Scribe :
- ssh addc
- . /etc/eole/samba4-vars.conf
- . /usr/lib/eole/samba4.sh
- /bin/rm /usr/sahre/eole/gpo/eole_script.tar.gz
- samba_export_gpo eole_script 

# le fichier /usr/share/eole/gpo/eole_script.tar.gz est crée
- exit

# retour sur scribe

- ./mount.eole-ci-tests 
- . getVMContext.sh
- cp /var/lib/lxc/addc/rootfs/usr/share/eole/gpo/eole_script.tar.gz /mnt/eole-ci-tests/output/$VM_OWNER/
- ls -l /mnt/eole-ci-tests/output/$VM_OWNER/
- exit

# retour sur PC perso

- VM_OWNER=ggrandgerard

- cd gpo-script
- git pull
- git status
- git checkout 2.7.2/master
- cd gpo/
- cp /mnt/eole-ci-tests/output/$VM_OWNER/eole_script.tar.gz eole_script.tar.gz
- cd ..
- ls -l gpo/eole_script.tar.gz
- git status
- git add gpo/eole_script.tar.gz
- git commit -m "blabla... REF #"
- git log
- git push
- git package 2.7.2/master
- git package -b -d eole-2.7.2/proposed-updates 2.7.2/master
- git checkout 2.8.0/master
- git pull
- git merge 2.7.2/master
- git status
- git push
- git package 2.8.0/master
- git package -b -d eole-2.8.0/proposed-updates 2.8.0/master
- git checkout 2.8.1/master
- git pull
- git merge 2.8.0/master
- git status
- git push
- git package 2.8.1/master
- git package -b -d eole-2.8.1/proposed-updates 2.8.1/master
- git checkout master
- git pull
- git merge 2.8.1/master
- git status
- git package 2.9.0/master
- git package -b -d eole-2.9/unstable 2.9.0/master
- git pull
- git push

# fini ouf!!!

==> eole-gpo-script_2.10.0-7.tar.gz: eole-gpo-script-7/README.md <==
## gpo-script

#Démarrer un etb1 scribe avec PC Win7 (x86), PC10 (ammd64), et Win11 (amd64)

... faire les modifications de installMinion.ps1 ou ps.ps1

Vérifier le fonctionnement des 3 PC en éxecutant :
- reboot
- controler c:\windows\temp\installMinion.log
- dans la session 'admin', vérifier %TEMP%\eole_script.log

#Aller sur Scribe :
- ssh addc
- . /etc/eole/samba4-vars.conf
- . /usr/lib/eole/samba4.sh
- /bin/rm /usr/share/eole/gpo/eole_script.tar.gz
- samba_export_gpo eole_script 

# le fichier /usr/share/eole/gpo/eole_script.tar.gz est crée
- exit

# retour sur scribe

- ./mount.eole-ci-tests 
- . getVMContext.sh
- cp /var/lib/lxc/addc/rootfs/usr/share/eole/gpo/eole_script.tar.gz /mnt/eole-ci-tests/output/$VM_OWNER/
- ls -l /mnt/eole-ci-tests/output/$VM_OWNER/
- exit

# retour sur PC perso

- VM_OWNER=ggrandgerard

- cd gpo-script
- git pull
- git status
- git checkout 2.7.2/master
- cd gpo/
- cp /mnt/eole-ci-tests/output/$VM_OWNER/eole_script.tar.gz eole_script.tar.gz
- cd ..
- ls -l gpo/eole_script.tar.gz
- git status
- git add gpo/eole_script.tar.gz
- git commit -m "blabla... REF #"
- git log
- git push
- git package 2.7.2/master
- git package -b -d eole-2.7.2/proposed-updates 2.7.2/master
- git checkout 2.8.0/master
- git pull
- git merge 2.7.2/master
- git status
- git push
- git package 2.8.0/master
- git package -b -d eole-2.8.0/proposed-updates 2.8.0/master
- git checkout 2.8.1/master
- git pull
- git merge 2.8.0/master
- git status
- git push
- git package 2.8.1/master
- git package -b -d eole-2.8.1/proposed-updates 2.8.1/master
- git checkout master
- git pull
- git merge 2.8.1/master
- git status
- git push
- git package 2.9.0/master
- git package -b -d eole-2.9.0/proposed-updates 2.9.0/master
- #git package -b -d eole-2.9/unstable 2.9.0/master
- git pull
- git push

# fini ouf!!!
